<?php
namespace MyMenu\Controllers;

use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\Session\Session;
use MyMenu\Libraries\KeyValueStorage;

class Informativos
{

    private $environment;
    private $dataSourceManager;
    private $parameterBagProvider;
    private $utilities;
    private $sessionManager;

    public function __construct($crudService, $environment, $dataSourceManager, $parameterBagProvider, $utilities, Session $sessionManager)
    {
        $this->crudService = $crudService;
        $this->environment = $environment;
        $this->dataSourceManager = $dataSourceManager;
        $this->parameterBagProvider = $parameterBagProvider;
        $this->utilities = $utilities;
        $this->sessionManager = $sessionManager;
    }

    public function getInformativos(Request\Filter $request, Response $response)
    {
        $dataSourceName = 'informativomymenu';
        $conditions = array(
            array(
                'columnName' => 'CDFILIAL',
                'operator' => '=',
                'value' => $this->environment->getCdfilial(),
            ),
            array(
                'columnName' => 'NRLOCALPESQ',
                'operator' => 'IS NULL OR NRLOCALPESQ =',
                'value' => KeyValueStorage::get("NRLOCALPESQ"),
            ),
            array(
                'columnName' => 'NRORG',
                'operator' => '=',
                'value' => $this->environment->getNrorg(),
            ),
        );
        try {
            
            $dataSet = $this->crudService->getFilteredDataSet($dataSourceName, $conditions);
            
            $rowsToReturn = $dataSet->getRows();
            for ($i = 0; $i < sizeof($rowsToReturn); $i++) {
                $this->utilities->concatFileServerPathToRow($rowsToReturn[$i], 'URLIMAGEM');
                $this->utilities->createStripedFieldInRow($rowsToReturn[$i], 'TXCONTEUDO', 'TXCONTEUDO_UNF');
            }


            $dataSetToReturn = new DataSet($dataSourceName, $rowsToReturn);
            $response->addDataSet($dataSetToReturn);
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
    public function lastAccessOnApp(Request $request, Response $response)
    {
        $lastAccs = $request->getRow()['lastAccs'];

        $dataSourceName = 'informativomymenu';
        $conditions = array(
            array(
                'columnName' => 'CDFILIAL',
                'operator' => '=',
                'value' => $this->environment->getCdfilial(),
            ),
            array(
                'columnName' => 'NRLOCALPESQ',
                'operator' => 'IS NULL OR NRLOCALPESQ =',
                'value' => KeyValueStorage::get("NRLOCALPESQ"),
            ),
            array(
                'columnName' => 'NRORG',
                'operator' => '=',
                'value' => $this->environment->getNrorg(),
            ),
        );
        try {
            $filterCriteria = new FilterCriteria(
                $dataSourceName,
                $conditions
            );

            $newFilterCriteria = $this->parameterBagProvider->getPopulatedFilterCriteria($filterCriteria);
            $dataSet = $this->dataSourceManager->findBy($newFilterCriteria);

            $rowsToReturn = $dataSet->getRows();

            $cont = 0;
            
            if($lastAccs !== null) {
                for ($i = 0; sizeof($rowsToReturn) > $i; $i++) {
                    $cur = $rowsToReturn[$i];

                    if($lastAccs - $cur['DATEFORMATEDTOCOMPARE'] < 0){
                        $cont++;
                    }
                }
                $cont = array('count' => $cont);
            }else{
                $cont = array('count' => sizeof($rowsToReturn));
            }

            $dataSetToReturn = new DataSet('count', $cont);
            $response->addDataSet($dataSetToReturn);
        } catch (\Exception $e) {
            $response->setError(new Error($e->getMessage(), 500));
        }
    }
}
