<?php
namespace MyMenu\Services;

use \Zeedhi\Framework\DataSource\FilterCriteria;

class ParameterBagProvider {
	
	protected $nameProvider;
	protected $parameterBag;
	
	public function __construct($nameProvider, $parameterBag) {
		$this->nameProvider = $nameProvider;
		$this->parameterBag = $parameterBag;
	}
	
	public function getPopulatedFilterCriteria(FilterCriteria $filterCriteria) {
        $dataSourceName = $filterCriteria->getDataSourceName();
        $query = $this->nameProvider->getDataSourceByName($dataSourceName)->getQuery();

        if ($query) {
            $parameterBagColumns = $this->buildParamBag($filterCriteria, $query);
            $filterCriteria = $this->populateParameterBag($filterCriteria, $parameterBagColumns);
        }

        return $filterCriteria;
    }

    private function buildParamBag($filterCriteria, $query) {
        $parameterBagColumns = array();
        $query = strtoupper($query);

        foreach ($filterCriteria->getConditions() as $condition) {
            $columnName = strtoupper($condition['columnName']);

            if (strpos($query, ':'.$columnName)) {
                $parameterBagColumns[] = $columnName;
            }
        }

        return $parameterBagColumns;
    }

    public function populateParameterBag(FilterCriteria $filterCriteria, $parameterBagColumns) {
        $conditions = array();

        foreach ($filterCriteria->getConditions() as $condition) {
            $columnName = $condition['columnName'];
            if (in_array($columnName, $parameterBagColumns)) {
                $this->parameterBag->set($columnName, $condition['value']);
            } else {
                $conditions[] = $condition;
            }
        }

        $newFilterCriteria = new FilterCriteria(
            $filterCriteria->getDataSourceName(),
            $conditions,
            $filterCriteria->getPage(),
            $filterCriteria->getPageSize()
        );

        $this->keepOrderBy($filterCriteria, $newFilterCriteria);

        return $newFilterCriteria;
    }

    public function keepOrderBy(FilterCriteria $oldFilterCriteria, FilterCriteria $newFilterCriteria) {
        $orderBy = $oldFilterCriteria->getOrderBy();

        if (!empty($orderBy)) {
            foreach ($orderBy as $key => $value) {
                $newFilterCriteria->addOrderBy($key, $value);
            }
        }
    }
}